#[repr(i32)]pub enum ChangeType {
Added = 0,
Invalidated = 1,
Mined = 2,
}Expand description
The type of change that occurred.
Variants
Added = 0
Represents a transaction being added to the mempool.
Invalidated = 1
Represents a transaction being invalidated and rejected from the mempool.
Mined = 2
Represents a transaction being mined into a block on the best chain and removed from the mempool.
Implementations
Sourceimpl ChangeType
impl ChangeType
Sourceimpl ChangeType
impl ChangeType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.